@@ -10,14 +10,13 @@ use std::{
 pub use crate::query_string::QueryString;
 
 
-/// A `http` related error
+/// A `http_header` related error
 #[derive(Debug, Copy, Clone, Eq, PartialEq)]
 pub enum HttpError {
 	InvalidEncoding,
 	TruncatedData,
 	ProtocolViolation,
-	ApiMisuse,
-	Debug
+	ApiMisuse
 }
 impl Display for HttpError {
 	fn fmt(&self, f: &mut Formatter) -> fmt::Result {
